#!/bin/bash

set -e

[ -z "$SLAPD" ] && SLAPD=/usr/sbin/slapd
[ -z "$SLAPADD" ] && SLAPADD=/usr/sbin/slapadd
SLAPD_URL=ldap://localhost:1389
LOGIN="-D cn=Manager,dc=my-domain,dc=com -w secret"

echo "Killing running slapd."
killall -9 slapd || :

echo "Cleaning."
rm -rf /tmp/bz742163
mkdir -p /tmp/bz742163/config
mkdir -p /tmp/bz742163/db

echo "Configuring."
$SLAPADD -F /tmp/bz742163/config -n 0 -l slapd.ldif

echo "Starting SLAPD."
$SLAPD -F /tmp/bz742163/config -h $SLAPD_URL
sleep 1

echo "Importing initial content."
ldapadd -H $SLAPD_URL -x $LOGIN -f root.ldif

reload_person() {
	ldapdelete -H $SLAPD_URL -x $LOGIN "cn=user,dc=my-domain,dc=com" &>/dev/null || :
	ldapadd -H $SLAPD_URL -x $LOGIN -f user.ldif &>/dev/null
}

run_tests() {
	for ldif_file in $@; do
		reload_person
		printf "[%s] " $ldif_file
		ldapmodify -H $SLAPD_URL -x $LOGIN -f $ldif_file &>/dev/null && ec=$? || ec=$?
		if [ $ec -eq 0 ]; then
			echo "OK"
		elif [ $ec -eq 19 ]; then
			echo "FAIL"
		else
			echo "UNEXPECTED ($ec)"
		fi
	done
	echo
}

echo "Operations with expected success."
run_tests t_ok_*.ldif

echo "Operations with expected failure."
run_tests t_fail_*.ldif

echo "Terminating slapd"
kill -TERM `cat /tmp/bz742163/slapd.pid`
